.. _input-formats:

=============
Input formats
=============

AMS currently supports the following input formats:

- ``.xlsx``: Excel spreadsheet file with AMS data
- ``.raw``: PSS/E RAW format
- ``.m``: MATPOWER format
- ``.py``: PYPOWER format

.. toctree::
   :maxdepth: 3

   xlsx
   psse
   matpower
   pypower
